==> epath-location-1.2.7-sources.jar: com/shitu/location/epathmap/utils/EpConstants.java <==
package com.shitu.location.epathmap.utils;

/**
 * author:lfei
 */
public class EpConstants {
    public static final double PACE = 1.5;
    public static final int NAV_STATUS_DEFAULT = 0, NAV_STATUS_SHOW_REGION_INFO = 1,
            NAV_STATUS_SHOW_SEARCH_RESULT = 2, NAV_STATUS_SHOW_PRE_INFO = 3, NAV_STATUS_NAVIGATING = 4,
            NAV_STATUS_NAVIGATING_PAUSE = 5, NAV_STATUS_FINISH = 6;
    public static final int DIRECTION_STRAIGHT = 0, DIRECTION_LEFT = 1, DIRECTION_RIGHT = 2,
            DIRECTION_STRAIGHT_LEFT = 3, DIRECTION_STRAIGHT_RIGHT = 4, DIRECTION_GO_ALONG = 5,
            DIRECTION_UPSTAIRS = 6, DIRECTION_DOWNSTAIRS = 7, DIRECTION_BEHIND_LEFT = 8,
            DIRECTION_BEHIND_RIGHT = 9, DIRECTION_NEAR_DESTINATION = 10;
    // stair(樓梯), elevator(電梯), escalator(手扶梯)
    public static final int CHANGE_FLOOR_STAIR = 1, CHANGE_FLOOR_ELEVATOR = 2, CHANGE_FLOOR_ESCALATOR = 3;
    public static final int NAV_MODE_SIMULATION = 0, NAV_MODE_BLE_GPS = 1, NAV_MODE_WIFI_GPS = 2;
    public static final String STAIR = "stair", ELEVATOR = "elevator", ESCALATOR = "escalator";
    //真实导航播报到达目的地距离
    public static final double REACH_REAL_DISTANCE = 6;
    //模拟导航播报到达目的地距离
    public static final double REACH_SIMULATION_DISTANCE = 2;
    //实时导航和模拟去除小的抖动点m
    public static final double SIMILAR_POINTS_RADIUS = 0.5;
    //前方xm左右转
    public static final double SWERVE_FRONT_DISTANCE = 5;
    //上下楼电梯/扶梯播报距离
    public static final double UPDOWN_DISTANCE = 5;
    //左右转
    public static final double SWERVE_DISTANCE = 3;
    //掉头
    public static final double TURN_ROUND_DISTANCE = 3;
    //请直行长度
    public static final double STRAIGHT_DISTANCE = 10;
    //播报直行的一段距离
    public static final double STRAIGHT_ONE_DISTANCE = 20;
    //更新位置间隔
    public static final int PERIOD_UPDATE_LOCATION_SHARE = 5000;
    //暂停后延迟center_lock
    public static final int DELAY_ON_PAUSE_TO_CENTER = 5;
    public static final double NAV_ACCURACY = 6; //去除第一个毛刺点长度
    public static final double NAV_ACCURACY_FIRST = 3; //去除第一次的关键节点的距离
    public static final double FlOOR_PHOTO_DISPALYER_DISTANCE = 7;
    public static final long FLOOR_PHOTO_DISPLER_TIME = 15000;
    public static final long VOICE_TIMER_STEP = 3000;
    public static final double NEAR_DESTINATION_DISTANCE = 21;

    public static final String HAS_GUIDE = "has_guide";
    public static final String NAV_TURN_LEFT = "左转";
    public static final String NAV_TURN_RIGHT = "右转";
    public static final String NAV_TURN_STRAIGHT_LEFT = "向左前方行走";
    public static final String NAV_TURN_STRAIGHT_RIGHT = "向右前方行走";
    public static final String NAV_TURN_BEHIND_LEFT = "向左后方行走";
    public static final String NAV_TURN_BEHIND_RIGHT = "向右后方行走";
    public static final String NAV_TURN_ROUND = "请调整方向与路线方向一致";
    public static final String NAV_REACH = "到达目的地";
    public static final String NAV_REACH_SIMU = "到达目的地";
    public static final String NAV_REACH_REAL = "您已经在目的地附近，感谢您使用释途导航！";
    public static final String NAV_GO_ALONG = "请沿路线行走";
    public static final String NAV_GO_STRAIGHT = "请直行";
    public static final String NAV_GO_STRAIGHT_CONTINUE = "请继续直行";
    public static final String NAV_PLEASE_UPSTAIRS = "上";
    public static final String NAV_PLEASE_DOWNSTAIRS = "下";

    public static final int RETRY_COUNT = 5;
}

==> epath-location-1.3.2-sources.jar: com/shitu/location/epathmap/utils/EpConstants.java <==
package com.shitu.location.epathmap.utils;

/**
 * author:lfei
 */
public class EpConstants {
    public static final double PACE = 1.5;
    public static final int NAV_STATUS_DEFAULT = 0, NAV_STATUS_SHOW_REGION_INFO = 1,
            NAV_STATUS_SHOW_SEARCH_RESULT = 2, NAV_STATUS_SHOW_PRE_INFO = 3, NAV_STATUS_NAVIGATING = 4,
            NAV_STATUS_NAVIGATING_PAUSE = 5, NAV_STATUS_FINISH = 6;
    public static final int DIRECTION_REACH = -1,DIRECTION_STRAIGHT = 0, DIRECTION_LEFT = 1, DIRECTION_RIGHT = 2,
            DIRECTION_STRAIGHT_LEFT = 3, DIRECTION_STRAIGHT_RIGHT = 4, DIRECTION_GO_ALONG = 5,
            DIRECTION_UPSTAIRS = 6, DIRECTION_DOWNSTAIRS = 7, DIRECTION_BEHIND_LEFT = 8,
            DIRECTION_BEHIND_RIGHT = 9, DIRECTION_NEAR_DESTINATION = 10;
    // stair(樓梯), elevator(電梯), escalator(手扶梯)
    public static final int CHANGE_FLOOR_STAIR = 0, CHANGE_FLOOR_ELEVATOR = 1, CHANGE_FLOOR_ESCALATOR = 2;
    public static final int NAV_MODE_SIMULATION = 0, NAV_MODE_BLE_GPS = 1, NAV_MODE_WIFI_GPS = 2;
    public static final String STAIR = "stair", ELEVATOR = "elevator", ESCALATOR = "escalator";
    //真实导航播报到达目的地距离
    public static final double REACH_REAL_DISTANCE = 6;
    //模拟导航播报到达目的地距离
    public static final double REACH_SIMULATION_DISTANCE = 2;
    //实时导航和模拟去除小的抖动点m
    public static final double SIMILAR_POINTS_RADIUS = 0.5;
    //前方xm左右转
    public static final double SWERVE_FRONT_DISTANCE = 5;
    //上下楼电梯/扶梯播报距离
    public static final double UPDOWN_DISTANCE = 5;
    //左右转
    public static final double SWERVE_DISTANCE = 3;
    //掉头
    public static final double TURN_ROUND_DISTANCE = 3;
    //请直行长度
    public static final double STRAIGHT_DISTANCE = 10;
    //播报直行的一段距离
    public static final double STRAIGHT_ONE_DISTANCE = 20;
    //更新位置间隔
    public static final int PERIOD_UPDATE_LOCATION_SHARE = 5000;
    //暂停后延迟center_lock
    public static final int DELAY_ON_PAUSE_TO_CENTER = 5;
    public static final double NAV_ACCURACY = 6; //去除第一个毛刺点长度
    public static final double NAV_ACCURACY_FIRST = 3; //去除第一次的关键节点的距离
    public static final double FlOOR_PHOTO_DISPALYER_DISTANCE = 7;
    public static final long FLOOR_PHOTO_DISPLER_TIME = 15000;
    public static final long VOICE_TIMER_STEP = 3000;
    public static final double NEAR_DESTINATION_DISTANCE = 21;

    public static final String HAS_GUIDE = "has_guide";
    public static final String NAV_TURN_LEFT = "左转";
    public static final String NAV_TURN_RIGHT = "右转";
    public static final String NAV_TURN_STRAIGHT_LEFT = "向左前方行走";
    public static final String NAV_TURN_STRAIGHT_RIGHT = "向右前方行走";
    public static final String NAV_TURN_BEHIND_LEFT = "向左后方行走";
    public static final String NAV_TURN_BEHIND_RIGHT = "向右后方行走";
    public static final String NAV_TURN_ROUND = "请调整方向与路线方向一致";
    public static final String NAV_REACH = "到达目的地";
    public static final String NAV_REACH_SIMU = "到达目的地";
    public static final String NAV_REACH_REAL = "您已经在目的地附近，感谢您使用释途导航！";
    public static final String NAV_GO_ALONG = "请沿路线行走";
    public static final String NAV_GO_STRAIGHT = "请直行";
    public static final String NAV_GO_STRAIGHT_CONTINUE = "请继续直行";
    public static final String NAV_PLEASE_UPSTAIRS = "上";
    public static final String NAV_PLEASE_DOWNSTAIRS = "下";

    public static final int RETRY_COUNT = 5;
}
